@@ -1,8 +1,7 @@
-from autopep8 import List
 from matplotlib.axes import Axes
 import matplotlib.pyplot as plt
 from pathlib import Path
-from typing import Optional, Union, Dict, Callable
+from typing import Optional, Union, Dict, Callable, List
 
 from matplotlib.collections import PathCollection
 from matplotlib.font_manager import FontProperties
